bluemath\_tk.wrappers.sfincs package
====================================

Submodules
----------

bluemath\_tk.wrappers.sfincs.sfincs\_example module
---------------------------------------------------

.. automodule:: bluemath_tk.wrappers.sfincs.sfincs_example
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.wrappers.sfincs.sfincs\_wrapper module
---------------------------------------------------

.. automodule:: bluemath_tk.wrappers.sfincs.sfincs_wrapper
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bluemath_tk.wrappers.sfincs
   :members:
   :undoc-members:
   :show-inheritance:
